@@ -22,7 +22,7 @@ use vars qw($VERSION %samsungLensTypes);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.55';
+$VERSION = '1.56';
 
 sub WriteSTMN($$$);
 sub ProcessINFO($$$);
@@ -979,6 +979,7 @@ my %formatMinMax = (
    # 0x0800 - unknown (29 bytes) (contains already-extracted EmbeddedAudioFileName)
    # 0x0830-name - seen '1165724808.pre'
    # 0x0830 - unknown (164004 bytes)
+   # 0x08c0-name - seen 'Auto_Enhance_Info' #forum16086
    # 0x08d0-name - seen 'Interactive_Panorama_Info'
    # 0x08d0 - unknown (7984 bytes)
    # 0x08e0-name - seen 'Panorama_Shot_Info'
@@ -988,6 +989,8 @@ my %formatMinMax = (
    # 0x0910 - string, seen 'Front_Cam_Selfie_Info'
    # 0x09e0-name - seen 'Burst_Shot_Info'
    # 0x09e0 - string, seen '489489125'
+   # 0x09e1-name - seen 'BurstShot_Best_Photo_Info' #forum16086
+   # 0x09f0-name - seen 'Pro_Mode_Info' #forum16086
    # 0x0a01-name - seen 'Image_UTC_Data'
     '0x0a01' => { #forum7161
         Name => 'TimeStamp',
@@ -999,6 +1002,7 @@ my %formatMinMax = (
     '0x0a20' => { Name => 'DualCameraImage', Groups => { 2 => 'Preview' }, Binary => 1 },
     '0x0a30-name' => 'EmbeddedVideoType', # ("MotionPhoto_Data")
     '0x0a30' => { Name => 'EmbeddedVideoFile', Groups => { 2 => 'Video' }, Binary => 1 }, #forum7161
+   # 0x0a41-name - seen 'BackupRestore_Data' #forum16086
    # 0x0aa1-name - seen 'MCC_Data'
    # 0x0aa1 - seen '204','222','234','302','429'
     '0x0aa1' => {
@@ -1254,15 +1258,39 @@ my %formatMinMax = (
         Name => 'DualShotExtra',
         SubDirectory => { TagTable => 'Image::ExifTool::Samsung::DualShotExtra' },
      },
+   # 0x0ab4-name - seen 'DualShot_Core_Info' #forum16086
    # 0x0ac0-name - seen 'ZoomInOut_Info' (SM-N950U)
    # 0x0ac0 - 2048 bytes of interesting stuff including firmware version? (SM-N950U)
+   # 0x0b30-name - seen 'Camera_Sticker_Info' #forum16086
     '0x0b40' => { # (SM-N975X front camera)
         Name => 'SingleShotMeta',
         SubDirectory => { TagTable => 'Image::ExifTool::Samsung::SingleShotMeta' },
      },
    # 0x0b41-name - seen 'SingeShot_DepthMap_1' (Yes, "Singe") (SM-N975X front camera)
     '0x0b41' => { Name => 'SingleShotDepthMap', Binary => 1 },
-   # 0x0ba1-name - seen 'Original_Path_Hash_Key', 'PhotoEditor_Re_Edit_Data'
+   # 0x0b51-name - seen 'Intelligent_PhotoEditor_Data' #forum16086
+   # 0x0b60-name - seen 'UltraWide_PhotoEditor_Data' #forum16086
+   # 0x0b90-name - seen 'Document_Scan_Info' #forum16086
+   # 0x0ba1-name - seen 'Original_Path_Hash_Key', 'PhotoEditor_Re_Edit_Data', 'deco_doodle_bitmap', 'deco_sticker_bitmap', 'deco_text_bitmap'
+   # 0x0ba2-name - seen 'Copy_Available_Edit_Info' #forum16086
+   # 0x0bc0-name - seen 'Single_Relighting_Bokeh_Info' #forum16086
+   # 0x0bd0-name - seen 'Dual_Relighting_Bokeh_Info' #forum16086
+   # 0x0be0-name - seen 'Livefocus_JDM_Info' #forum16086
+   # 0x0bf0-name - seen 'Remaster_Info' #forum16086
+   # 0x0c21-name - seen 'Portrait_Effect_Info' #forum16086
+   # 0x0c51-name - seen 'Samsung_Capture_Info' #forum16086
+   # 0x0c61-name - seen 'Camera_Capture_Mode_Info' #forum16086
+   # 0x0c71-name - seen 'Pro_White_Balance_Info' #forum16086
+   # 0x0c81-name - seen 'Watermark_Info' #forum16086
+   # 0x0cc1-name - seen 'Color_Display_P3' #forum16086
+   # 0x0cd2-name - seen 'Photo_HDR_Info' #forum16086
+   # 0x0ce1-name - seen 'Gallery_DC_Data' #forum16086
+   # 0x0d01-name - seen 'Camera_Scene_Info', 'Camera_Scene_Info2', 'Camera_Scene_Info3' #forum16086
+   # 0x0d11-name - seen 'Video_Snapshot_Info' #forum16086
+   # 0x0d21-name - seen 'Camera_Scene_Info' #forum16086
+   # 0x0d31-name - seen 'Food_Blur_Effect_Info' #forum16086
+   # 0x0d91-name - seen 'PEg_Info' #forum16086
+   # 0x0da1-name - seen 'Captured_App_Info' #forum16086
    # 0xa050-name - seen 'Jpeg360_2D_Info' (Samsung Gear 360)
    # 0xa050 - seen 'Jpeg3602D' (Samsung Gear 360)
    # 0x0c81-name - seen 'Watermark_Info'
@@ -1546,7 +1574,7 @@ sub ProcessSamsung($$$)
     my ($buff, $buf2, $index, $offsetPos, $audioNOff, $audioSize);
 
     unless ($raf) {
-        $raf = new File::RandomAccess($$dirInfo{DataPt});
+        $raf = File::RandomAccess->new($$dirInfo{DataPt});
         $et->VerboseDir('SamsungTrailer');
     }
     return 0 unless $raf->Seek(-6-$offset, 2) and $raf->Read($buff, 6) == 6 and
@@ -1675,7 +1703,7 @@ SamBlock:
                 # add a fixup so the calling routine can apply further shifts if necessary
                 require Image::ExifTool::Fixup;
                 my $fixup = $$dirInfo{Fixup};
-                $fixup or $fixup = $$dirInfo{Fixup} = new Image::ExifTool::Fixup;
+                $fixup or $fixup = $$dirInfo{Fixup} = Image::ExifTool::Fixup->new;
                 $fixup->AddFixup(length($buff) - $offsetPos);
                 $fixup->AddFixup(length($buff) - $offsetPos + 4);
             }
@@ -1697,7 +1725,7 @@ sub WriteSTMN($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
     # create a Fixup for the PreviewImage
-    $$dirInfo{Fixup} = new Image::ExifTool::Fixup;
+    $$dirInfo{Fixup} = Image::ExifTool::Fixup->new;
     my $val = Image::ExifTool::WriteBinaryData($et, $dirInfo, $tagTablePtr);
     # force PreviewImage into the trailer even if it fits in EXIF segment
     $$et{PREVIEW_INFO}{IsTrailer} = 1 if $$et{PREVIEW_INFO};
